package seznam;

import java.awt.Color;
import java.awt.Component;
import java.awt.Font;

import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.ListCellRenderer;

/**
 * Vykreslovač buněk pro prvky seznamu - objekty třídy MyColor.
 * Vykreslovač funguje jako razítko. Když potřebuje seznam vykreslit
 * nějakou buňku, požádá tento vykreslovač o komponentu, kterou poté
 * použije k vykreslení na určitém místě (její metodu paint). Seznam
 * JList si tedy do sebe neukládá žádné komponenty. Proto můžeme vždy
 * z metody getListCellRenderer vracet tu samou komponentu a JList ji
 * vždy pouze jednou použije pro vykreslení. Proto tato třída dědí z
 * komponenty JLabel a z metody getListCellRendererComponent vrací
 * sama sebe. V této metodě vždy nastaví svoje vlastnosti (barvu,
 * text, ...) podle předaného objketu typu MyColor.
 */
public class ColorCellRenderer extends JLabel implements
		ListCellRenderer {

	/**
	 * Vytvoří novou instanci třídy ColorCellRenderer.
	 */
	public ColorCellRenderer() {
		this.setFont(new Font("Serif", Font.BOLD, 20));
		this.setOpaque(true);
	}

	@Override
	public Component getListCellRendererComponent(JList list,
			Object value, int index, boolean isSelected,
			boolean cellHasFocus) {
		MyColor color = (MyColor) value;

		this.setText(color.getColorName());
		this.setBackground(color.getColor());
		if (isSelected) {
			this.setForeground(Color.WHITE);
		} else {
			this.setForeground(Color.BLACK);
		}
		return this;
	}
}